/*
	LUSScreenSaver Plugin LUSSSPicture ( SlideShowModule )
	Copyright (C) 2003 ONO,Masayuki.<mono101@skill-engineering.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "LUSSSPictureSetting.h"
#include <qfile.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qvariant.h>
#include <qwhatsthis.h>
#include <qlineedit.h>
#include <qcheckbox.h>
#include <qlabel.h>
#include <qspinbox.h>
#include <qgroupbox.h>
#include <qpe/config.h>
#include <qpe/qpeapplication.h>
#include <sl/slfileselector.h>

#include <qtextcodec.h>
#define _T(str) QTextCodec::codecForLocale()->toUnicode(str)

LUSSSPictureBrowseDir::LUSSSPictureBrowseDir( const QString& dir, QWidget* parent,  const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
	setWState( WState_Reserved1 );

	if ( !name )
	{
		setName( "LUSSSPictureBrowseDir" );
	}
	setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)5,
												sizePolicy().hasHeightForWidth() ) );
	QString caption;
	caption = _T( "ǥ쥯ȥ" );
	setCaption( caption );

	BaseLayout = new QVBoxLayout( this ); 
	BaseLayout->setSpacing( 6 );
	BaseLayout->setMargin( 11 );

	DirBrowser = new SlFileSelector( dir, "image/*", this, "DirBrowser" );
	DirBrowser->setFocusMode( SlFileSelector::ByTab );
	BaseLayout->addWidget( DirBrowser );

	showMaximized();
}

LUSSSPictureBrowseDir::~LUSSSPictureBrowseDir()
{
}

void LUSSSPictureBrowseDir::closeEvent( QCloseEvent *e )
{
	e->accept();
}

void LUSSSPictureBrowseDir::accept()
{
	m_sPath = DirBrowser->currentDir();
	emit done( Accepted );
}

QString LUSSSPictureBrowseDir::getPath()
{
	return m_sPath;
}

LUSSSPictureSetting::LUSSSPictureSetting( QWidget* parent,  const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
	if ( ! name )
	{
		setName( "SettingDialog" );
	}

	setCaption( "SETTINGS" );

	BaseLayout = new QVBoxLayout( this ); 
	BaseLayout->setSpacing( 6 );
	BaseLayout->setMargin( 11 );

	BaseGroupBox = new QGroupBox( this, "BaseGroupBox" );
	BaseGroupBox->setTitle( "" );
	BaseGroupBox->setColumnLayout(0, Qt::Vertical );
	BaseGroupBox->layout()->setSpacing( 0 );
	BaseGroupBox->layout()->setMargin( 0 );
	BaseGroupBoxLayout = new QVBoxLayout( BaseGroupBox->layout() );
	BaseGroupBoxLayout->setAlignment( Qt::AlignTop );
	BaseGroupBoxLayout->setSpacing( 6 );
	BaseGroupBoxLayout->setMargin( 11 );

	PathFuncLayout = new QHBoxLayout( this );
	PathFuncLayout->setSpacing( 6 );
	PathFuncLayout->setMargin( 11 );

	ChecksLayout = new QHBoxLayout( this );
	ChecksLayout->setSpacing( 6 );
	ChecksLayout->setMargin( 11 );

	IntervalLayout = new QHBoxLayout( this );
	IntervalLayout->setSpacing( 6 );
	IntervalLayout->setMargin( 11 );

	DefButtonsLayout = new QHBoxLayout( this );
	DefButtonsLayout->setSpacing( 6 );
	DefButtonsLayout->setMargin( 11 );

	Config cfg( "LUSScreenSaver" );
	cfg.setGroup( "LUSSSPicture" );

	PathEdit = new QLineEdit( BaseGroupBox, "PathEdit" );
	QString path = cfg.readEntry( "Path" );
	if ( path.isEmpty() || ! QFile::exists( path ) )
	{
		path = QPEApplication::documentDir() + "Image_Files/";
	}
	PathEdit->setText( path );

	PathFuncLabel = new QLabel( _T( "᡼Ǽǥ쥯ȥ" ), BaseGroupBox, "PathFuncLabel" );

	BrowseDirButton = new QPushButton( BaseGroupBox, "BrowseDirButton" );
	BrowseDirButton->setText( "..." );

	PathFuncLayout->addWidget( PathEdit );
	PathFuncLayout->addWidget( BrowseDirButton );

	IntervalLabel = new QLabel( _T( "饤ɥ硼ֳ" ), BaseGroupBox, "IntervalLabel" );

	IntervalSpin = new QSpinBox( 1, 600, 1, BaseGroupBox, "IntervalSpin" );
	IntervalSpin->setSuffix( _T( " " ) );
	IntervalSpin->setValue( cfg.readNumEntry( "Interval", 5 ) );

	IntervalLayout->addWidget( IntervalLabel );
	IntervalLayout->addWidget( IntervalSpin );

	ShowCounterCheck = new QCheckBox( _T( "" ), BaseGroupBox, "ShowCounterCheck" );
	ShowCounterCheck->setChecked( cfg.readBoolEntry( "ShowCounter", FALSE ) );

	RandomCheck = new QCheckBox( _T(""), BaseGroupBox, "RandomCheck" );
	RandomCheck->setChecked( cfg.readBoolEntry( "Random", FALSE ) );
	
	ShowFileNameCheck = new QCheckBox( _T("ե͡"), BaseGroupBox, "ShowFileNameCheck" );
	ShowFileNameCheck->setChecked( cfg.readBoolEntry( "ShowFileName", FALSE ) );

	ChecksLayout->addWidget( ShowCounterCheck );
	ChecksLayout->addWidget( RandomCheck );
	ChecksLayout->addWidget( ShowFileNameCheck );

	PushButton1 = new QPushButton( this, "PushButton1" );
	PushButton1->setText( _T( "Ŭ" ) );

	PushButton2 = new QPushButton( this, "PushButton2" );
	PushButton2->setText( _T( "󥻥" ) );
	
	DefButtonsLayout->addWidget( PushButton1 );
	DefButtonsLayout->addWidget( PushButton2 );

	BaseGroupBoxLayout->addWidget( PathFuncLabel );
	BaseGroupBoxLayout->addLayout( PathFuncLayout );
	BaseGroupBoxLayout->addLayout( IntervalLayout );
	BaseGroupBoxLayout->addLayout( ChecksLayout );
	BaseLayout->addWidget( BaseGroupBox );
	BaseLayout->addLayout( DefButtonsLayout );
	
	connect( BrowseDirButton, SIGNAL( clicked() ), this, SLOT( browseDir() ) );
	connect( RandomCheck, SIGNAL( stateChanged(int) ), this, SLOT( changedRandomCheck(int) ) );
	connect( ShowCounterCheck, SIGNAL( stateChanged(int) ), this, SLOT( changedShowCounterCheck(int) ) );
	connect( PushButton1 ,SIGNAL( clicked() ), this, SLOT( accept() ) );
	connect( PushButton2 ,SIGNAL( clicked() ), this, SLOT( close() ) );

	showMaximized();
}

void LUSSSPictureSetting::changedRandomCheck( int state )
{
	if ( state )
	{
		ShowCounterCheck->setChecked( FALSE );
	}
}

void LUSSSPictureSetting::changedShowCounterCheck( int state )
{
	if ( state )
	{
		RandomCheck->setChecked( FALSE );
	}
}

void LUSSSPictureSetting::browseDir()
{
	LUSSSPictureBrowseDir dlg( PathEdit->text(), this, tr("Dir. Selector"), TRUE, 0 );
	if ( dlg.exec() == QDialog::Accepted )
	{
		QString sPath = dlg.getPath();
		if( sPath[ sPath.length() - 1 ] != '/' )
		{
			sPath.append( '/' );
		}
		PathEdit->setText( sPath );
	}
}

void LUSSSPictureSetting::accept()
{
	Config cfg( "LUSScreenSaver" );
	cfg.setGroup( "LUSSSPicture" );

	if ( ! PathEdit->text().isEmpty() )
	{
		cfg.writeEntry( "Path", PathEdit->text() );
	}
	
	cfg.writeEntry( "Interval", IntervalSpin->value() );
	cfg.writeEntry( "Random", RandomCheck->isChecked() );
	cfg.writeEntry( "ShowCounter", ShowCounterCheck->isChecked() );
	cfg.writeEntry( "ShowFileName", ShowFileNameCheck->isChecked() );
	close();
}

void LUSSSPictureSetting::closeEvent( QCloseEvent* e )
{
	e->accept();
}


LUSSSPictureSetting::~LUSSSPictureSetting()
{
    // no need to delete child widgets, Qt does it all for us
}

