/*
	LUSScreenSaver Plugin LUSSSPicture ( SlideShowModule )
	Copyright (C) 2003 ONO,Masayuki.<mono101@skill-engineering.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "LUSSSPictureWidget.h"
#include <stdlib.h>

LUSSSPictureWidget::LUSSSPictureWidget( QWidget* parent, const char* name )
	: QWidget( parent, name, WDestructiveClose )
	, m_nCnt( -1 )
	, m_nInterval( 5000 )
	, m_nImages( 0 )
{
	clearWFlags( WStyle_Title );
	m_bLoading = FALSE;
	m_bDo = FALSE;
	m_bShowCounter = FALSE;
	m_bShowFileName = FALSE;
	m_bRandom = FALSE;
}

LUSSSPictureWidget::~LUSSSPictureWidget(  )
{
}

void LUSSSPictureWidget::Start()
{
	m_bDo = TRUE;

	setBackgroundColor( QColor( 0, 0, 0 ) );
	erase();
	show();

	QString msg( "...Wait..." );
	QFontMetrics fm( font() );
	QPoint msgPoint( ( width() - fm.width( msg ) ) / 2, ( height() - fm.height() ) / 2 );
	QPainter p;
	p.begin( this );
	p.setPen( QColor( 255, 255, 255 ) );
	p.drawText( msgPoint, msg );
	p.end();

	Config cfg( "LUSScreenSaver" );
	cfg.setGroup( "LUSSSPicture" );
	m_nInterval = cfg.readNumEntry( "Interval", 5 ) * 1000;
	m_bShowCounter = cfg.readBoolEntry( "ShowCounter", FALSE  );
	m_bRandom = cfg.readBoolEntry( "Random", FALSE  );
	if ( m_bRandom && m_bShowCounter )
	{
		m_bShowCounter = FALSE;
		m_bRandom = FALSE;
		cfg.writeEntry( "ShowCounter", FALSE  );
		cfg.writeEntry( "Random", FALSE  );
	}
	m_bShowFileName = cfg.readBoolEntry( "ShowFileName", FALSE  );

	if ( m_nCnt == -1 )
	{
		Config cfg( "LUSScreenSaver" );
		cfg.setGroup( "LUSSSPicture" );

		QString path = cfg.readEntry( "Path" );

		if ( path.isEmpty() || ! QFile::exists( path ) )
		{
			path = QPEApplication::documentDir() + "Image_Files/";
		}

		QDir oDir( path );
		oDir.setFilter( QDir::Files | QDir::Hidden );
		oDir.setSorting( QDir::Name );
		oDir.setNameFilter( "*.png;*.PNG;*.gif;*.GIF;*.jpg;*.JPG;*.bmp;*.BMP" );

		const QFileInfoList *pList = oDir.entryInfoList();
		QFileInfoListIterator it( *pList );
		QFileInfo *fi;
		while ( (int)( fi = it.current() ) )
		{
			m_FileList << fi->absFilePath();
			++it;
		}
	}

	if ( m_FileList.count() > 0 )
	{
		m_nImages = m_FileList.count();
		m_nCnt = m_bRandom ? rand() / ( RAND_MAX / ( m_nImages + 1 ) ) : 0;
		readyImage();
		QTimer::singleShot( 100, this, SLOT( timerDo() ) );
	}
}

void LUSSSPictureWidget::Stop()
{
	m_bDo = FALSE;
}

void LUSSSPictureWidget::timerDo()
{
	if ( !m_bDo )
	{
		return;
	}

	if ( m_bLoading )
	{
		QTimer::singleShot( 10, this, SLOT( timerDo() ) );
		return;
	}

	erase();
	bitBlt( this, ( width() - m_oBuffer.width() ) / 2, ( height() - m_oBuffer.height() ) / 2, &m_oBuffer );

	if ( m_bShowCounter || m_bShowFileName )
	{
		QString msg;
		if ( m_bShowFileName )
		{
			QFileInfo fi( m_FileList[ m_nCnt ] );
			QString tmsg = QString( " %1" ).arg( fi.fileName() );
			msg.append( tmsg );
		}
		if ( m_bShowCounter )
		{
			QString tmsg = QString( " %1 / %2" ).arg( m_nCnt + 1 ).arg( m_nImages );
			msg.append( tmsg );
		}
		QFontMetrics fm( font() );
		QPainter p;
		p.begin( this );
		p.setPen( QColor( 255, 255, 255 ) );
		p.drawText( QPoint( 0, fm.height() ), msg );
		p.end();
	}

	QTimer::singleShot( m_nInterval, this, SLOT( timerDo() ) );

	if ( m_bRandom )
	{
		m_nCnt = rand() / ( RAND_MAX / ( m_nImages + 1 ) );
	}
	else
	if ( ++ m_nCnt >= ( signed int )m_FileList.count() )
	{
		m_nCnt = 0;
	}

	readyImage();
}

void LUSSSPictureWidget::readyImage()
{
	m_bLoading = TRUE;

	QString imgPath = m_FileList[ m_nCnt ];

	m_oBuffer.load( imgPath );
	
	QSize sizeScaling = m_oBuffer.size();

	if ( sizeScaling.height() > height() )
	{
		sizeScaling.setWidth( (double)sizeScaling.width() * ( (double)height() / (double)sizeScaling.height() ) );
		sizeScaling.setHeight( height() );
	}

	if ( sizeScaling.width() > width() )
	{
		sizeScaling.setHeight( (double)sizeScaling.height() * ( (double)width() / (double)sizeScaling.width() ) );
		sizeScaling.setWidth( width() );
	}

	if ( m_oBuffer.size() != sizeScaling )
	{
		m_oBuffer = m_oBuffer.smoothScale( sizeScaling.width(), sizeScaling.height() );
	}

	m_bLoading = FALSE;
}

