/*
	LUSScreenSaver Plugin LUSSSTemplate ( Default like )
	Copyright (C) 2003 ONO,Masayuki.<mono101@skill-engineering.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "LUSSSTemplateWidget.h"

LUSSSTemplateWidget::LUSSSTemplateWidget( QWidget* parent, const char* name )
	: QWidget( parent, name, WDestructiveClose )
{
	clearWFlags( WStyle_Title );
}

LUSSSTemplateWidget::~LUSSSTemplateWidget(  )
{
}

void LUSSSTemplateWidget::Start()
{
	Config cfg( "LUSScreenSaver" );
	cfg.setGroup( "LUSSSTemplate" );
	m_bDate = cfg.readBoolEntry( "Date", TRUE );
	m_bTime = cfg.readBoolEntry( "Time", TRUE );

	setBackgroundColor( QColor( 255, 255, 255 ) );
	erase();

	show();

	repaint( TRUE );

	timer = new QTimer(this);
	connect( timer, SIGNAL( timeout() ), this, SLOT( timerDo() ) );
	timer->start( 4500, false ); // timerDo() will be called per 4.5sec
}

void LUSSSTemplateWidget::Stop()
{
	if ( !timer )
	{
		timer->stop();
		delete timer;
	}
}

void LUSSSTemplateWidget::timerDo()
{
	repaint( TRUE );
}

void LUSSSTemplateWidget::paintEvent( QPaintEvent *e )
{
	QWidget::paintEvent( e );
	QPixmap buffer( size() );
	buffer.fill( QColor(255,255,255) );

	QString msg;
	if ( !m_bDate && m_bTime  )
	{
		QTime nowTime = QTime::currentTime();
		msg = nowTime.toString();
	}
	else if ( m_bDate && !m_bTime )
	{
		QDate nowDate = QDate::currentDate();
		msg = QString( "%1/%2/%3" )
								.arg( nowDate.year() )
								.arg( nowDate.month() )
								.arg( nowDate.day() );
	}
	else
	{
		QDate nowDate = QDate::currentDate();
		QTime nowTime = QTime::currentTime();
		msg = QString( "%1/%2/%3 %4" )
								.arg( nowDate.year() )
								.arg( nowDate.month() )
								.arg( nowDate.day() )
								.arg( nowTime.toString() );
	}

	QFontMetrics fm( font() );
	int x = rand() / ( RAND_MAX / ( width() - fm.width( msg ) ) + 1 );
	int y = rand() / ( RAND_MAX / ( height() - fm.height() )  + 1 ) + fm.height();

	QPainter painter;
	painter.begin( &buffer );
	painter.setPen( Qt::black );
	painter.setFont( font() );
	painter.drawText( x, y, msg, -1 );
	painter.end();
	bitBlt( this, 0, 0, &buffer );
}

